#!/usr/bin/env python
# -*- coding: utf-8 -*-

#    Copyright (C) 2009 Luca Vaudano vaudano@gmail.com
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.Warning
from core.modules.constants import *

# Singleton
class Status:
    
    class __impl:
        
        # Initialization
        def __init__(self):
            status = 0
            steps = 1

        # Get status
        def getStatus(self):
            return status
        
        # Set UI
        def setUI(self, ui):
            self.ui = ui
        
        # Set steps to do
        def setSteps(self, steps):
            self.steps = steps
        
        # Set status
        def setStatus(self, step, value):
            singleStepMax = 100 / self.steps
            multiple = singleStepMax / MAX_SINGLE_STEP
            status = (singleStepMax * step) + (value * multiple)
            if self.ui is not None:
                self.ui.setStatus(status)
        
    # storage for the instance reference
    __instance = None

    def __init__(self):
        
        # Check whether we already have an instance
        if Status.__instance is None:
            
            # Create instance
            Status.__instance = Status.__impl()

        # Store instance reference as the only member in the handle
        self.__dict__['_Singleton__instance'] = Status.__instance

    def __getattr__(self, attr):
        """ Delegate access to implementation """
        return getattr(self.__instance, attr)

    def __setattr__(self, attr, value):
        """ Delegate access to implementation """
        return setattr(self.__instance, attr, value)
