#!/usr/bin/env python
# -*- coding: utf-8 -*-

#    Copyright (C) 2009 Luca Vaudano vaudano@gmail.com
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.Warning
import elementary
import textwrap
import re
import os

import logging
log = logging.getLogger("babiloo.efl.definition_ui")

from efl.constants import *

class DefinitionPage():
    
    # Initialization
    def __init__(self, main):
        self.main = main
        self.box = None

    def setupUi(self):

        # Box object
        self.box = elementary.Box(self.main.win)
        self.box.horizontal_set(False)
        self.main.win.resize_object_add(self.box)
        self.box.size_hint_weight_set(1.0, 1.0)
        self.box.show()

        # Horizontal box with clear, word field and search button
        toolbarBox = elementary.Box(self.main.win)
        toolbarBox.horizontal_set(True)
        toolbarBox.homogenous_set(True)
        toolbarBox.size_hint_weight_set(1.0, 0.0)
        toolbarBox.size_hint_align_set(-1.0, 0.0)
  
        # Dictionaries icon
        self.dictionariesButton = elementary.Button(self.main.win)
        dictionariesIcon = elementary.Icon(self.dictionariesButton)
        dictionariesIcon.file_set(DICTIONARIES_ICON)
        self.dictionariesButton.icon_set(dictionariesIcon)
        self.dictionariesButton.size_hint_weight_set(1.0, 1.0)
        self.dictionariesButton.size_hint_align_set(-1.0, -1.0)
        toolbarBox.pack_end(self.dictionariesButton)
        self.dictionariesButton.show()
    
        # Settings toolbar icon
        self.settingsButton = elementary.Button(self.main.win)
        settingsIcon = elementary.Icon(self.settingsButton)
        settingsIcon.file_set(SETTINGS_ICON)
        self.settingsButton.icon_set(settingsIcon)
        self.settingsButton.size_hint_weight_set(1.0, 1.0)
        self.settingsButton.size_hint_align_set(-1.0, -1.0)
        toolbarBox.pack_end(self.settingsButton)
        self.settingsButton.show()

        # Speak toolbar icon
        self.speakButton = elementary.Button(self.main.win)
        speakIcon = elementary.Icon(self.speakButton)
        speakIcon.file_set(SPEAK_ICON)
        self.speakButton.icon_set(speakIcon)
        self.speakButton.size_hint_weight_set(1.0, 1.0)
        self.speakButton.size_hint_align_set(-1.0, -1.0)
        toolbarBox.pack_end(self.speakButton)
        self.speakButton.show()

        self.box.pack_end(toolbarBox)
        toolbarBox.show()

        # Horizontal box with clear, word field and search button
        bx2 = elementary.Box(self.main.win)
        bx2.horizontal_set(True)
        #bx2.homogenous_set(True)
        bx2.size_hint_weight_set(1.0, 0.0)
        bx2.size_hint_align_set(-1.0, 0.0)

        # Clear button
        self.clearButton = elementary.Button(self.main.win)
        ic = elementary.Icon(self.clearButton)
        ic.file_set(CLEAR_ICON)
        self.clearButton.icon_set(ic)
        # workround for nice position
        self.clearButton.label_set("   ")
        self.clearButton.size_hint_weight_set(0.0, 1.0)
        self.clearButton.size_hint_align_set(-1.0, -1.0)
        bx2.pack_end(self.clearButton)
        self.clearButton.show()

        # Word field
        self.word = elementary.Entry(self.main.win)
        self.word.line_wrap_set(False)
        self.word.entry_set("")
        self.word.single_line_set(True)
        self.word.scale_set(1.5)
        self.word.size_hint_weight_set(1.0, 1.0)
        self.word.size_hint_align_set(-1.0, -1.0)
        bx2.pack_end(self.word)
        self.word.show()
        
        # Search button
        self.searchButton = elementary.Button(self.main.win)
        ic = elementary.Icon(self.main.win)
        ic.file_set(SEARCH_ICON)
        self.searchButton.icon_set(ic)
        # workround for nice position
        self.searchButton.label_set("   ")
        self.searchButton.size_hint_weight_set(0.0, 1.0)
        self.searchButton.size_hint_align_set(-1.0, -1.0)
        bx2.pack_end(self.searchButton)
        self.searchButton.show()

        self.box.pack_end(bx2)
        bx2.show()
    
        # Frame
        self.fr = elementary.Frame(self.main.win)
        self.fr.label_set(' ')
        self.fr.size_hint_weight_set(1.0, 1.0)
        self.fr.size_hint_align_set(-1.0, -1.0)

        # Entry scroller
        sc = elementary.Scroller(self.main.win)
        sc.size_hint_weight_set(1.0, 1.0)
        sc.size_hint_align_set(-1.0, -1.0)
        ## hide scrollbars
        #sc.policy_set(2, 2)
        ## make it non-bouncing
        #sc.drag_bouncy_set(0)

        # Definition text area
        self.definition = elementary.Entry(self.main.win)
        #self.definition.line_wrap_set(True)
        self.definition.line_wrap_set(False)
        self.definition.scale_set(1.25)
        self.definition.entry_set("")
        self.definition.single_line_set(False)
        self.definition.editable_set(False)
        self.definition.size_hint_weight_set(1.0, 1.0)
        self.definition.size_hint_align_set(-1.0, -1.0)

        sc.content_set(self.definition)
        self.fr.content_set(sc) 

        self.definition.show()
        self.fr.show()
        sc.show()

        self.box.pack_end(self.fr)

    def frame_title_set(self, text):
        if self.box:
            if (len(text) > WIDTH):
                text = text[:WIDTH-3] + '...'
            self.fr.label_set(text)

    def content_set(self, text):
        definitionString = textwrap.fill(text, WIDTH)
        definitionString = re.sub("\n", "<br>", definitionString)
        self.definition.entry_set(definitionString)
