#!/usr/bin/env python
# -*- coding: utf-8 -*-

#    Copyright (C) 2009 Luca Vaudano vaudano@gmail.com
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.Warning
import elementary

import logging
log = logging.getLogger("babiloo.efl.dictionariesPage")

from efl.constants import *

class DictionariesPage():

    # Initialization
    def __init__(self, main):
        self.main = main
        self.box = None

    #
    # self.box
    #   scroller
    #     boxScroller
    #       for each Section
    #         frameSection
    #         boxSection
    # quitDictionariesWin
    def setupUi(self):
        
        # Box Window with scroller and quit button
        self.box = elementary.Box(self.main.win)
        self.box.horizontal_set(False)
        self.main.win.resize_object_add(self.box)
        self.box.size_hint_weight_set(1.0, 1.0)
        self.box.size_hint_align_set(-1, -1)
        self.box.show()

        # Scroller
        scroller = elementary.Scroller(self.main.win)
        scroller.bounce_set(0, 0)
        scroller.size_hint_weight_set(1.0, 1.0)
        scroller.size_hint_align_set(-1.0, -1.0)
        self.box.pack_end(scroller)
        scroller.show()

        # Quit button
        self.quitDictionariesWin = elementary.Button(self.main.win)
        self.quitDictionariesWin.label_set("Quit")
        self.quitDictionariesWin.size_hint_align_set(-1.0, 0.0)
        ic = elementary.Icon(self.quitDictionariesWin)
        ic.file_set( QUIT_ICON)
        ic.smooth_set(1)
        ic.scale_set(1, 1)
        self.quitDictionariesWin.icon_set(ic)
        self.quitDictionariesWin.show()
        self.box.pack_end(self.quitDictionariesWin)

        # Box inside scroller
        boxScroller = elementary.Box(self.main.win)
        boxScroller.horizontal_set(False)
        boxScroller.size_hint_weight_set(1.0, -1.0)
        scroller.content_set(boxScroller)
        boxScroller.show()

        # Frame for dictionary section
        self.createDictionaryFrame()
        boxScroller.pack_end(self.frameDictionary)
        
        # Frame for sound dictionary section
        self.createSoundDictionaryFrame()
        boxScroller.pack_end(self.frameSoundDictionary)

    def createDictionaryFrame(self):
        self.frameDictionary = elementary.Frame(self.main.win)
        self.frameDictionary.label_set("Dictionary FILE NAME")
        self.frameDictionary.size_hint_align_set(-1.0, 0.0)
        self.frameDictionary.show()

        # Box for dictionary section
        boxDictionary = elementary.Box(self.main.win)
        boxDictionary.horizontal_set(False)
        boxDictionary.size_hint_align_set(-1.0, 0.0)
        boxDictionary.show()

        # Box object with 'New dictionary' and 'DictionaryPathEntry'
        boxDictionaryPathEntry= elementary.Box(self.main.win)
        boxDictionaryPathEntry.horizontal_set(True)
        boxDictionaryPathEntry.size_hint_weight_set(1.0, 1.0)
        boxDictionaryPathEntry.show()

        # New dictionary button
        self.newDictionaryButton = elementary.Button(self.main.win)
        ic = elementary.Icon(self.newDictionaryButton)
        ic.file_set(NEW_DICTIONARY_ICON)
        self.newDictionaryButton.icon_set(ic)
        # workround for nice position
        self.newDictionaryButton.label_set("  ")
        self.newDictionaryButton.size_hint_weight_set(0.0, 1.0)
        self.newDictionaryButton.size_hint_align_set(-1.0, -1.0)
        self.newDictionaryButton.show()

        # Dictionary path entry
        self.dictionaryEntry = elementary.Entry(self.main.win)
        self.dictionaryEntry.line_wrap_set(False)
        self.dictionaryEntry.entry_set('')
        self.dictionaryEntry.single_line_set(True)
        self.dictionaryEntry.editable_set(False)
        self.newDictionaryButton.size_hint_weight_set(0.0, 1.0)
        self.dictionaryEntry.size_hint_align_set(-1.0, -1.0)
        self.dictionaryEntry.scale_set(1.25)
        
        self.dictionaryEntry.show()

        boxDictionaryPathEntry.pack_end(self.newDictionaryButton)
        boxDictionaryPathEntry.pack_end(self.dictionaryEntry)

        # File selector
        self.saveDictionary = elementary.Button(self.main.win)
        self.saveDictionary.label_set("Save ( it takes time! )")
        self.saveDictionary.size_hint_align_set(-1.0, 0.0)
        self.saveDictionary.show()

        boxDictionary.pack_end(boxDictionaryPathEntry)
        boxDictionary.pack_end(self.saveDictionary)

        self.frameDictionary.content_set(boxDictionary)


    def createSoundDictionaryFrame(self):
        self.frameSoundDictionary = elementary.Frame(self.main.win)
        self.frameSoundDictionary.label_set("Sound dictionary PATH")
        self.frameSoundDictionary.size_hint_align_set(-1.0, 0.0)
        self.frameSoundDictionary.show()

        # Box for sound dictionary section
        boxSoundDictionary = elementary.Box(self.main.win)
        boxSoundDictionary.horizontal_set(False)
        boxSoundDictionary.size_hint_align_set(-1.0, 0.0)
        boxSoundDictionary.show()

        # Box object with 'New sound dictionary' and 'SoundDictionaryPathEntry'
        boxSoundDictionaryPathEntry= elementary.Box(self.main.win)
        boxSoundDictionaryPathEntry.horizontal_set(True)
        boxSoundDictionaryPathEntry.size_hint_weight_set(1.0, 1.0)
        boxSoundDictionaryPathEntry.show()

        # New dictionary button
        self.newSoundDictionaryButton = elementary.Button(self.main.win)
        ic = elementary.Icon(self.newSoundDictionaryButton)
        ic.file_set(NEW_SOUND_DICTIONARY_ICON)
        self.newSoundDictionaryButton.icon_set(ic)
        # workround for nice position
        self.newSoundDictionaryButton.label_set("  ")
        self.newSoundDictionaryButton.size_hint_weight_set(0.0, 1.0)
        self.newSoundDictionaryButton.size_hint_align_set(-1.0, -1.0)
        self.newSoundDictionaryButton.show()

        # Dictionary path entry
        self.soundDictionaryEntry = elementary.Entry(self.main.win)
        self.soundDictionaryEntry.line_wrap_set(False)
        self.soundDictionaryEntry.entry_set('')
        self.soundDictionaryEntry.single_line_set(True)
        self.soundDictionaryEntry.editable_set(False)
        self.newSoundDictionaryButton.size_hint_weight_set(0.0, 1.0)
        self.soundDictionaryEntry.size_hint_align_set(-1.0, -1.0)
        self.soundDictionaryEntry.scale_set(1.25)
        
        self.soundDictionaryEntry.show()

        boxSoundDictionaryPathEntry.pack_end(self.newSoundDictionaryButton)
        boxSoundDictionaryPathEntry.pack_end(self.soundDictionaryEntry)

        # File selector
        self.saveSoundDictionary = elementary.Button(self.main.win)
        self.saveSoundDictionary.label_set("Save")
        self.saveSoundDictionary.size_hint_align_set(-1.0, 0.0)
        self.saveSoundDictionary.show()

        boxSoundDictionary.pack_end(boxSoundDictionaryPathEntry)
        boxSoundDictionary.pack_end(self.saveSoundDictionary)

        self.frameSoundDictionary.content_set(boxSoundDictionary)

                