#!/usr/bin/env python
# -*- coding: utf-8 -*-

#    Copyright (C) 2009 Luca Vaudano vaudano@gmail.com
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.Warning
from time import time
import os

import ecore
import elementary

from core.modules import *
import core.dictionary.engine as engine

import logging
log = logging.getLogger("babiloo.efl.main_model")

from efl.constants import *
from efl.config import Config
from core.modules.status import Status
from utils_ui import UtilsUi

config = Config()
utils = UtilsUi()

class Model():
    
    # Destroy called on destroy window
    def destroy(self, obj, data):
    
        # Save settings
        config.save()
        
        # Exit
        elementary.exit()

    # Load database for Neo or Netbook
    def loadDatabase(self):

        # Load database
        if config.get('dictionary_path') != '':
            
            # Show ''Loading database ...''
            self.create_loadingFrame("Please wait...<br>Loading dictionary...")
            
            # it doesn't work well on OpenGeu / Ubuntu + OzOs
            # it works well on Neo and Elive
            ecore.idler_add(self.loadDatabaseCore)

        else:
            self.create_dialog("No dictionary to load")
        
    # TODO Set percentage status
    def setStatus(self, status):
        print "%d" % status
        #self.loadinglabel.label_set("Loading dictionary...<br>     %d%%" %status)
        
    # Call the babiloo core module for loading the database
    def loadDatabaseCore(self):
        nowtime = time()
        self.dictionary_name = ' '
        try:        
            self.engine = engine.DictionaryEngine()
            
            self.testdict = self.engine.loadDictionary(config.get('dictionary_path'))
            self.dictionary_name = self.engine.getDictionary( self.testdict['dict'].getUniqueId() ).getName()
        except:
            log.error("Dictionary can't be loaded!")
            self.create_dialog("Dictionary can't be loaded!")

        # Hide the loading frame
        self.loading.hide()

        # Put the database name on the frame title
        self.definitionPage.frame_title_set(self.dictionary_name)
        log.info("Dictionary loaded in %.2f sec" % (time() - nowtime) )
        
        # Close the thread
        return None

    def speak(self, obj, data):
        
        # check if the player exists
        if not os.path.exists(config.get('player')): 
            self.create_dialog("Please install %s" %config.get('player'));
            return
            
        # check if the sound dictionary path is set
        if config.get('sound_dictionary_path') == '': 
            self.create_dialog("Sound dictionary path not set");
            return
            
        # check if the sound dictionary path exists
        if not os.path.exists(config.get('sound_dictionary_path')): 
            self.create_dialog("Sound dictionary path not valid %s" %config.get('sound_dictionary_path'));
            return
            
        # searched word
        speakWord = data.entry_get()
        speakWord = speakWord.strip()
        
        # if the user inserted the word in the entry filed
        if len(speakWord) != 0:
            speakWord = config.get('sound_dictionary_path') + '/' + speakWord[0] + '/' + speakWord + '.wav'
            log.debug("Speak %s" % speakWord)
            if not os.path.exists(speakWord): 
                self.create_dialog("Word not found");
                return
            speakCmd = config.get('player') + " %s" % speakWord
            log.debug(speakCmd)
            os.system(speakCmd + ' &')

    def clear_text_field(self, obj, data):
        data.entry_set("")
    
    def search_word(self, obj, input):
        
        # if the database is loaded
        if config.get('dictionary_path') != '':

            # searched word
            self.word = input.entry_get()
            self.word = self.word.strip()
        
            # if the user inserted the word in the entry filed
            if len(self.word) != 0:
                log.debug("Searched word: %s" % self.word)
            
                try:
                    result = self.engine.search(self.word, self.testdict['dict'].getUniqueId())

                    # Format the dictionary result
                    self.definitionPage.content_set( result.content() )

                except KeyError:
                    self.create_dialog("Word %s not found" %self.word)
                except:
                    self.create_dialog("Error during the search of %s" %self.word)
            
        else:
            self.create_dialog("You have to load the dictionary")

    # Browse for selecting the dictionary file
    def newDictionaryClicked(self, obj):
        utils.fileSelectorUI()

        def fs_cb_done(obj, event_info, data):
            if event_info is not None:
                
                # Cut br. Depends of the Elementary version!
                event_info = event_info.replace('<br>', '')
                
                # If is not a directory
                if event_info[-1] != '/':
                    # Used in the save action
                    self.newDictionary = event_info
                    utils.filename_set(self.dictionariesPage.dictionaryEntry, self.newDictionary)
                    utils.fileSelectorWindow.hide()
                else:
                    self.create_dialog("You have to select the dictionary file.")
            else:
                data.delete()
        utils.fileSelector.callback_done_add(fs_cb_done, utils.fileSelectorWindow)

    # Browse for selecting the sound dictionary path
    def newSoundDictionaryClicked(self, obj):
        utils.fileSelectorUI()

        def fs_cb_done(obj, event_info, data):
            if event_info is not None:
                
                # Cut br. Depends of the Elementary version!
                event_info = event_info.replace('<br>', '')
                
                # If is a directory
                if event_info[-1] == '/':
                    # Used in the save action
                    self.newSoundDictionary = event_info
                    utils.filename_set(self.dictionariesPage.soundDictionaryEntry, self.newSoundDictionary)
                    utils.fileSelectorWindow.hide()
                else:
                    self.create_dialog("You have to select a dictionary.<br>\
The directory should contain folders<br>\
a, b, c and so on")
            else:
                data.delete()
        utils.fileSelector.callback_done_add(fs_cb_done, utils.fileSelectorWindow)

    # Browse for selecting the player
    def newPlayerClicked(self, obj):
        utils.fileSelectorUI()

        def fs_cb_done(obj, event_info, data):
            if event_info is not None:
                
                # Cut br. Depends of the Elementary version!
                event_info = event_info.replace('<br>', '')
                
                # If is not a directory
                if event_info[-1] != '/':
                    # Used in the save action
                    self.newPlayer = event_info
                    utils.filename_set(self.settingsPage.playerEntry, self.newPlayer)
                    utils.fileSelectorWindow.hide()
                else:
                    self.create_dialog("You have to select player executable file.")
            else:
                data.delete()
        utils.fileSelector.callback_done_add(fs_cb_done, utils.fileSelectorWindow)

    # Load the new dictionary
    def saveDictionaryClicked(self, obj):
        self.promoteDefinitionPage()
        if self.newDictionary is not None:
            log.info("Save dictionary in the configuration %s" % self.newDictionary)
            config.set('dictionary_path', self.newDictionary)
            self.loadDatabase()
        
    # Load the new sound dictionary
    def saveSoundDictionaryClicked(self, obj):
        self.promoteDefinitionPage()
        if self.newSoundDictionary is not None:
            log.info("Save sound dictionary in the configuration %s" % self.newSoundDictionary)
            config.set('sound_dictionary_path', self.newSoundDictionary)

    # Load player
    def savePlayerClicked(self, obj):
        self.promoteDefinitionPage()
        if self.newPlayer is not None:
            log.info("Save player in the configuration %s" % self.newPlayer)
            config.set('player', self.newPlayer)

    def promote(self, boxToPromote):
        if self.definitionPage.box:
            self.definitionPage.box.hide()
        if self.dictionariesPage.box:
            self.dictionariesPage.box.hide()
        if self.settingsPage.box:
            self.settingsPage.box.hide()
        if self.aboutPage.box:
            self.aboutPage.box.hide()
        self.win.resize(SCREEN_WIDTH, SCREEN_HEIGHT)
        boxToPromote.show()
        
    def promoteDefinitionPage(self, obj=None, event=None, data=None):
        
        if not self.definitionPage.box:

            # Setup UI
            self.definitionPage.setupUi()
            
            # Bind methods
            self.definitionPage.dictionariesButton.callback_clicked_add(self.promoteDictionariesPage)
            self.definitionPage.settingsButton.callback_clicked_add(self.promoteSettingsPage)
            self.definitionPage.speakButton.callback_clicked_add(self.speak, self.definitionPage.word)
            self.definitionPage.clearButton.callback_clicked_add(self.clear_text_field, self.definitionPage.word)
            self.definitionPage.searchButton.callback_clicked_add(self.search_word, self.definitionPage.word)
            self.definitionPage.definition.callback_activated_add(self.search_word, self.definitionPage.word)

        # Put the definition page on the top of the pager
        self.promote(self.definitionPage.box)
        
    def promoteDictionariesPage(self, obj=None, event=None, data=None):
        
        if not self.dictionariesPage.box:

            # Setup UI
            self.dictionariesPage.setupUi()
            
            # Set quit function
            self.dictionariesPage.quitDictionariesWin.callback_clicked_add(self.promoteDefinitionPage)
        
            # Show the loaded dictionary
            self.newDictionary = config.get('dictionary_path')
        
            # Set dictionary filename from configuration
            utils.filename_set(self.dictionariesPage.dictionaryEntry, self.newDictionary)
        
            # Set new dictionary function
            self.dictionariesPage.newDictionaryButton.callback_clicked_add(self.newDictionaryClicked)
        
            # Set save function
            self.dictionariesPage.saveDictionary.callback_clicked_add(self.saveDictionaryClicked)

            # Set the loaded sound dictionary path
            self.newSoundDictionary = config.get('sound_dictionary_path')
        
            # Set dictionary filename from configuration
            utils.filename_set(self.dictionariesPage.soundDictionaryEntry, self.newSoundDictionary)
        
            # Set new dictionary function
            self.dictionariesPage.newSoundDictionaryButton.callback_clicked_add(self.newSoundDictionaryClicked)
        
            # Set save function
            self.dictionariesPage.saveSoundDictionary.callback_clicked_add(self.saveSoundDictionaryClicked)

        # Put the dictionaries page on the top of the pager
        self.promote(self.dictionariesPage.box)        

    def promoteSettingsPage(self, obj=None, event=None, data=None):
                
        if not self.settingsPage.box:
                
            # Setup UI
            self.settingsPage.setupUi()
            
            # Quit button
            self.settingsPage.quitSettingsWin.callback_clicked_add(self.promoteDefinitionPage)

            # Show the loaded player
            self.newPlayer = config.get('player')
        
            # Set dictionary filename from configuration
            utils.filename_set(self.settingsPage.playerEntry, self.newPlayer)
        
            # Set new dictionary function
            self.settingsPage.newPlayerButton.callback_clicked_add(self.newPlayerClicked)
        
            # Set save function
            self.settingsPage.savePlayer.callback_clicked_add(self.savePlayerClicked)

           # About button
            self.settingsPage.aboutPageWin.callback_clicked_add(self.promoteAboutPage)
        
        # Put the setting page on the top of the pager
        self.promote(self.settingsPage.box)

    def promoteAboutPage(self, obj=None, event=None, data=None):
                
        if not self.aboutPage.box:
                
            # Setup UI
            self.aboutPage.setupUi()
            
            # Quit button
            self.aboutPage.quitAboutWin.callback_clicked_add(self.promoteDefinitionPage)
        
        # Put the setting page on the top of the pager
        self.promote(self.aboutPage.box)
        