#!/usr/bin/env python
# -*- coding: utf-8 -*-

#    Copyright (C) 2009 Luca Vaudano vaudano@gmail.com
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.Warning
import elementary

import logging
log = logging.getLogger("babiloo.efl.definition_ui")

from definition_ui import DefinitionPage
from dictionaries_ui import DictionariesPage
from settings_ui import SettingsPage
from about_ui import AboutPage

from efl.constants import *

class Ui_Main(object):
    
    def setupUi(self):
        
        # Basic window - name, title
        self.win = elementary.Window(APP_NAME, elementary.ELM_WIN_BASIC)
        self.win.title_set(APP_NAME)

        # Standard background
        bg = elementary.Background(self.win)
        self.win.resize_object_add(bg)
        bg.size_hint_weight_set(1.0, 1.0)
        bg.show()

        # Different contents on the same page
        self.definitionPage = DefinitionPage(self)
        self.dictionariesPage = DictionariesPage(self)
        self.settingsPage = SettingsPage(self)
        self.aboutPage = AboutPage(self)

        # Show definition page
        self.promoteDefinitionPage()
        
        # Window size (size for pc application, for neo means full screen)
        self.win.resize(SCREEN_WIDTH, SCREEN_HEIGHT)
        self.win.show()
        
    def create_dialog(self, text):
        self.dialog = elementary.Box(self.win)
        
        loadingframe = elementary.Frame(self.win)
        loadingframe.style_set("outdent_bottom")
        loadingframe2 = elementary.Frame(self.win)
        loadingframe2.style_set("outdent_top")
        loadingframe2.size_hint_weight_set(0.0, 0.0)
        loadingframe2.size_hint_align_set(0.5, 0.5)
        
        # Internal box object
        self.internalBox = elementary.Box(self.win)
        self.messageEntry = elementary.Entry(self.win)
        self.messageEntry.line_wrap_set(False)
        self.messageEntry.entry_set(text)
        self.messageEntry.editable_set(False)
        self.internalBox.pack_end(self.messageEntry)
        self.messageEntry.show()
        self.okButton = elementary.Button(self.win)
        self.okButton.label_set('OK')
        self.okButton.size_hint_weight_set(0.0, 0.0)
        self.okButton.size_hint_align_set(0.5, 0.5)
        self.internalBox.pack_end(self.okButton)
        self.okButton.show()
        
        loadingframe.content_set(loadingframe2)
        loadingframe2.content_set(self.internalBox)
        self.win.resize_object_add(self.dialog)
        self.dialog.pack_start(loadingframe)
        self.internalBox.show()
        loadingframe.show()
        loadingframe2.show()
        self.dialog.show()

	self.okButton.callback_clicked_add(self.dialogClicked, self.dialog)

    def dialogClicked(self, obj, data):
        data.hide()

    def create_loadingFrame(self, text):
        
        self.loading = elementary.Box(self.win)
        
        loadingframe = elementary.Frame(self.win)
        loadingframe.style_set("outdent_bottom")
        loadingframe2 = elementary.Frame(self.win)
        loadingframe2.style_set("outdent_top")
        loadingframe2.size_hint_weight_set(0.0, 0.0)
        loadingframe2.size_hint_align_set(0.5, 0.5)
        
        loadinglabel = elementary.Label(self.win)
        loadinglabel.label_set(text)
        
        loadingframe.content_set(loadingframe2)
        loadingframe2.content_set(loadinglabel)
        self.win.resize_object_add(self.loading)
        self.loading.pack_start(loadingframe)
        loadinglabel.show()
        loadingframe.show()
        loadingframe2.show()
        self.loading.show()
