#!/usr/bin/env python
# -*- coding: utf-8 -*-

#    Copyright (C) 2009 Luca Vaudano vaudano@gmail.com
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.Warning
import elementary

import logging
log = logging.getLogger("babiloo.efl.settingsPage")

from efl.constants import *

class SettingsPage():

    # Initialization
    def __init__(self, main):
        self.main = main
        self.box = None

    # Setup user interface
    def setupUi(self):

        # Box Window with scroller and quit button
        self.box = elementary.Box(self.main.win)
        self.box.horizontal_set(False)
        self.main.win.resize_object_add(self.box)
        self.box.size_hint_weight_set(1.0, 1.0)
        self.box.size_hint_align_set(-1, -1)
        self.box.show()

        # Scroller
        scroller = elementary.Scroller(self.main.win)
        scroller.bounce_set(0, 0)
        scroller.size_hint_weight_set(1.0, 1.0)
        scroller.size_hint_align_set(-1.0, -1.0)
        self.box.pack_end(scroller)
        scroller.show()

       # About button
        self.aboutPageWin = elementary.Button(self.main.win)
        self.aboutPageWin.label_set("About")
        self.aboutPageWin.size_hint_align_set(-1.0, 0.0)
        ic = elementary.Icon(self.aboutPageWin)
        ic.file_set( ABOUT_ICON)
        ic.smooth_set(1)
        ic.scale_set(1, 1)
        self.aboutPageWin.icon_set(ic)
        self.aboutPageWin.show()
        self.box.pack_end(self.aboutPageWin)

        # Quit button
        self.quitSettingsWin = elementary.Button(self.main.win)
        self.quitSettingsWin.label_set("Quit")
        self.quitSettingsWin.size_hint_align_set(-1.0, 0.0)
        ic = elementary.Icon(self.quitSettingsWin)
        ic.file_set( QUIT_ICON)
        ic.smooth_set(1)
        ic.scale_set(1, 1)
        self.quitSettingsWin.icon_set(ic)
        self.quitSettingsWin.show()
        self.box.pack_end(self.quitSettingsWin)

        # Box inside scroller
        boxScroller = elementary.Box(self.main.win)
        boxScroller.horizontal_set(False)
        boxScroller.size_hint_weight_set(1.0, -1.0)
        scroller.content_set(boxScroller)
        boxScroller.show()

        # Frame for dictionary section
        self.createPlayerFrame()
        boxScroller.pack_end(self.framePlayer)

    def createPlayerFrame(self):
        self.framePlayer = elementary.Frame(self.main.win)
        self.framePlayer.label_set("Player FILE NAME")
        self.framePlayer.size_hint_align_set(-1.0, 0.0)
        self.framePlayer.show()

        # Box for dictionary section
        boxPlayer = elementary.Box(self.main.win)
        boxPlayer.horizontal_set(False)
        boxPlayer.size_hint_align_set(-1.0, 0.0)
        boxPlayer.show()

        # Box object with 'New player' and 'PlayerPathEntry'
        boxPlayerPathEntry= elementary.Box(self.main.win)
        boxPlayerPathEntry.horizontal_set(True)
        boxPlayerPathEntry.size_hint_weight_set(1.0, 1.0)
        boxPlayerPathEntry.show()

        # New player button
        self.newPlayerButton = elementary.Button(self.main.win)
        ic = elementary.Icon(self.newPlayerButton)
        ic.file_set(NEW_PLAYER_ICON)
        self.newPlayerButton.icon_set(ic)
        # workround for nice position
        self.newPlayerButton.label_set("  ")
        self.newPlayerButton.size_hint_weight_set(0.0, 1.0)
        self.newPlayerButton.size_hint_align_set(-1.0, -1.0)
        self.newPlayerButton.show()

        # Player path entry
        self.playerEntry = elementary.Entry(self.main.win)
        self.playerEntry.line_wrap_set(False)
        self.playerEntry.entry_set('')
        self.playerEntry.single_line_set(True)
        self.playerEntry.editable_set(False)
        self.newPlayerButton.size_hint_weight_set(0.0, 1.0)
        self.playerEntry.size_hint_align_set(-1.0, -1.0)
        self.playerEntry.scale_set(1.25)
        
        self.playerEntry.show()

        boxPlayerPathEntry.pack_end(self.newPlayerButton)
        boxPlayerPathEntry.pack_end(self.playerEntry)

        # File selector
        self.savePlayer = elementary.Button(self.main.win)
        self.savePlayer.label_set("Save")
        self.savePlayer.size_hint_align_set(-1.0, 0.0)
        self.savePlayer.show()

        boxPlayer.pack_end(boxPlayerPathEntry)
        boxPlayer.pack_end(self.savePlayer)

        self.framePlayer.content_set(boxPlayer)

